@@ -18,6 +18,7 @@
 
 #include "editbox.h"
 #include "editor.h"
+#include "helpbox.h"
 #include "dialogline.h"
 #include "inputline.h"
 #include "speller.h"
@@ -43,11 +44,11 @@ EditBox::action_entry EditBox::actions_table[] = {
     ADD_ACTION(EditBox, move_backward_char,
 	    N_("Move back a character")),
     ADD_ACTION(EditBox, move_beginning_of_line,
-	    N_("Move to the start of the current line, logical")),
+	    N_("Move to the beginning of the current line, logical")),
     ADD_ACTION(EditBox, move_beginning_of_visual_line,
-	    N_("Move to the start of the current line, visual")),
+	    N_("Move to the beginning of the current line, visual")),
     ADD_ACTION(EditBox, key_home,
-	    N_("Move to the start of the current line")),
+	    N_("Move to the beginning of the current line")),
     ADD_ACTION(EditBox, move_end_of_line,
 	    N_("Move to the end of the current line")),
     ADD_ACTION(EditBox, move_last_modification,
@@ -65,13 +66,13 @@ EditBox::action_entry EditBox::actions_table[] = {
     ADD_ACTION(EditBox, move_end_of_buffer,
 	    N_("Move to the end of the buffer")),
     ADD_ACTION(EditBox, move_beginning_of_buffer,
-	    N_("Move to the start of the buffer")),
+	    N_("Move to the beginning of the buffer")),
     ADD_ACTION(EditBox, move_backward_word,
-	    N_("Move to the start of the current or previous word")),
+	    N_("Move to the beginning of the current or previous word")),
     ADD_ACTION(EditBox, move_forward_word,
 	    N_("Move to the end of the current or next word")),
     ADD_ACTION(EditBox, delete_backward_word,
-	    N_("Delete to the start of the current or previous word")),
+	    N_("Delete to the beginning of the current or previous word")),
     ADD_ACTION(EditBox, delete_forward_word,
 	    N_("Delete to the end of the current or next word")),
     ADD_ACTION(EditBox, toggle_dir_algo,
@@ -100,8 +101,8 @@ EditBox::action_entry EditBox::actions_table[] = {
 	    N_("Translate next character")),
     ADD_ACTION(EditBox, justify,
 	    N_("Justify the current or next paragraph")),
-    ADD_ACTION(EditBox, delete_end_of_paragraph,
-	    N_("Delete [to] end of paragraph")),
+    ADD_ACTION(EditBox, cut_end_of_paragraph,
+	    N_("Cut [to] end of paragraph")),
     ADD_ACTION(EditBox, undo,
 	    N_("Undo the last change")),
     ADD_ACTION(EditBox, redo,
@@ -180,6 +181,7 @@ binding_entry EditBox::bindings_table[] = {
     { Event(ALT, 'o'), "move_last_modification" },
     { Event(KEY_BACKSPACE), "delete_backward_char" },
     { Event(KEY_DC), "delete_forward_char" },
+    { Event(CTRL, 'd'), "delete_forward_char" },
     { Event(ALT, 'h'), "toggle_alt_kbd" },
     { Event(KEY_F(12)), "toggle_alt_kbd" },
     { Event(ALT, '>'), "move_end_of_buffer" },
@@ -194,7 +196,7 @@ binding_entry EditBox::bindings_table[] = {
     { Event(ALT, 'w'), "toggle_wrap" },
     { Event(CTRL, 'q'), "set_translate_next_char" },
     { Event(CTRL, 'j'), "justify" },
-    { Event(CTRL, 'k'), "delete_end_of_paragraph" },
+    { Event(CTRL, 'k'), "cut_end_of_paragraph" },
     { Event(CTRL, 'r'), "redo" },
     { Event(CTRL, 'u'), "undo" },
     { Event(CTRL, 'c'), "copy" },
@@ -248,7 +250,7 @@ Editor::action_entry Editor::actions_table[] = {
     ADD_ACTION(Editor, save_file_as,
 	    N_("Save file in another name")),
     ADD_ACTION(Editor, insert_file,
-	    N_("Insert file from disk (or read from pipe) into the current buffer")),
+	    N_("Insert file from disk (or read from pipe) into the buffer")),
     ADD_ACTION(Editor, change_tab_width,
 	    N_("Change the TAB character size")),
     ADD_ACTION(Editor, change_justification_column,
@@ -280,7 +282,7 @@ Editor::action_entry Editor::actions_table[] = {
     ADD_ACTION(Editor, toggle_arabic_shaping,
 	    N_("Toggle Arabic shaping and Lam-Alif ligature")),
     ADD_ACTION(Editor, write_selection_to_file,
-	    N_("Write selection to file")),
+	    N_("Write the selected text (or the whole text, if none selected) to a file/pipe")),
     ADD_ACTION(Editor, change_scroll_step,
 	    N_("Change the scroll step (# of lines to scroll up/down when cursor at top/bottom)")),
     ADD_ACTION(Editor, load_unload_speller,
@@ -297,8 +299,10 @@ Editor::action_entry Editor::actions_table[] = {
 	    N_("Toogle big cursor (console only); useful if you're visually impaired")),
     ADD_ACTION(Editor, toggle_graphical_boxes,
 	    N_("Use graphical characters for the menus and scrollbar")),
-    ADD_ACTION(Editor, escape_to_vim,
-	    N_("Shell out to Vim")),
+    ADD_ACTION(Editor, external_edit_prompt,
+	    N_("Edit this file with an external editor, prompt for editor command")),
+    ADD_ACTION(Editor, external_edit_no_prompt,
+	    N_("Edit this file with an external editor (using previously entered command)")),
     ADD_ACTION(Editor, menu_set_scrollbar_none, NULL),
     ADD_ACTION(Editor, menu_set_scrollbar_left, NULL),
     ADD_ACTION(Editor, menu_set_scrollbar_right, NULL),
@@ -339,7 +343,8 @@ binding_entry Editor::bindings_table[] = {
     { Event(ALT, 'S'), "load_unload_speller" },
     { Event(KEY_F(9)), "menu" },
     { Event(KEY_F(10)), "menu" },
-    { Event(KEY_F(8)), "escape_to_vim" },
+    { Event(ALT, 0, KEY_F(8)), "external_edit_prompt" },
+    { Event(KEY_F(8)),         "external_edit_no_prompt" },
     { Event(VIRTUAL, 3000), "toggle_big_cursor" },
     { Event(VIRTUAL, 1100), "toggle_graphical_boxes" },
     { Event(VIRTUAL, 1200), "menu_set_scrollbar_none" },
@@ -392,6 +397,8 @@ HelpBox::action_entry HelpBox::actions_table[] = {
     ADD_ACTION(HelpBox, end_modal, NULL),
     ADD_ACTION(HelpBox, layout_windows, NULL),
     ADD_ACTION(HelpBox, refresh_and_center, NULL),
+    ADD_ACTION(HelpBox, move_to_toc, NULL),
+    ADD_ACTION(HelpBox, pop_position, NULL),
     END_ACTIONS
 };
 
@@ -404,6 +411,8 @@ binding_entry HelpBox::bindings_table[] = {
     { Event(ALT, 'x'),  "end_modal" },
     { Event(ALT, 'X'),  "end_modal" },
     { Event(0, ESC),    "end_modal" },
+    { Event(ALT, 'b'),  "pop_position" },
+    { Event(ALT, 't'),  "move_to_toc" },
     END_BINDINGS
 };
 
