@@ -74,6 +74,7 @@ EditBox::EditBox()
     rfc2646_trailing_space = true;
     data_transfer.in_transfer = false;
     old_width		= -1;
+    prev_command_type = current_command_type = cmdtpUnknown;
     paragraphs.push_back(new Paragraph());
 }
 
@@ -339,10 +340,13 @@ void EditBox::cut_or_copy(bool just_copy)
 
 // copy_text() -- copies "len" characters to the clipboard. advances the
 // cursor.
+// if the 'append' parameter is true, the characters don't replace the
+// clipboard but are appended to it.
 
-void EditBox::copy_text(int len)
+void EditBox::copy_text(int len, bool append)
 {
-    clipboard.clear();
+    if (!append)
+	clipboard.clear();
     while (len > 0) {
 	if (cursor.pos == curr_para()->str.len()) {
 	    if (cursor.para < parags_count() - 1) {
@@ -1390,6 +1394,7 @@ INTERACTIVE void EditBox::toggle_alt_kbd()
 
 bool EditBox::handle_event(const Event &evt)
 {
+    current_command_type = cmdtpUnknown;
     if (evt.is_literal()) {
 	unichar ch = evt.ch;
 	if (in_translation_mode()) {
@@ -1404,9 +1409,13 @@ bool EditBox::handle_event(const Event &evt)
 	default:
 	    insert_char(ch);
 	}
+	prev_command_type = current_command_type;
 	return true;
-    } else
-	return Dispatcher::handle_event(evt);
+    } else {
+	bool ret = Dispatcher::handle_event(evt);
+	prev_command_type = current_command_type;
+	return ret;
+    }
 }
 
 static bool is_empty_or_starts_with_space(const unistring &str) {
@@ -1668,16 +1677,24 @@ INTERACTIVE void EditBox::delete_backward_char()
     }
 }
 
-// delete_end_of_paragraph() - interactive command to delete till
+// cut_end_of_paragraph() - interactive command to cut till
 // end of paragraph. If the cursor is already at the end, it deletes
 // the EOP (ala emacs).
 
-INTERACTIVE void EditBox::delete_end_of_paragraph()
+INTERACTIVE void EditBox::cut_end_of_paragraph()
 {
+    int count;
     if (cursor.pos == curr_para()->str.len())
-	delete_text(1);
+	count = 1;
     else
-	delete_text(curr_para()->str.len() - cursor.pos);
+	count = curr_para()->str.len() - cursor.pos;
+
+    Point orig_cursor = cursor;
+    copy_text(count, (prev_command_type == cmdtpKill));
+    cursor = orig_cursor;
+    delete_text(count);
+
+    current_command_type = cmdtpKill;
 }
 
 // delete_paragraph() - interactive command to delete the current
