@@ -386,6 +386,12 @@ protected:
     // Where the last edit operation took place?
     Point last_modification;
 
+    // We emulate some emacs commands (e.g. C-k) with these
+    // flags. When prev_command_type is cmdtpKill, we know
+    // we need to append to the clipboard.
+    enum CommandType { cmdtpUnknown, cmdtpKill };
+    CommandType prev_command_type, current_command_type;
+
 private:
     
     struct _t_data_transfer {
@@ -649,7 +655,7 @@ protected:
 public:
 
     INTERACTIVE void delete_paragraph();
-    INTERACTIVE void delete_end_of_paragraph();
+    INTERACTIVE void cut_end_of_paragraph();
     INTERACTIVE void delete_forward_word();
     INTERACTIVE void delete_backward_word();
     INTERACTIVE void delete_forward_char();
@@ -693,7 +699,7 @@ protected:
     inline void set_contextual_dir(Paragraph &p, direction_t dir,
 				   bool update_display);
     int calc_distance(Point p1, Point p2);
-    void copy_text(int len);
+    void copy_text(int len, bool append = false);
     void cut_or_copy(bool just_copy);
     inline unichar get_eop_char(eop_t eop);
     inline unichar get_curr_eop_char();
@@ -795,6 +801,8 @@ protected:
     unichar get_char_repr(unichar ch);
     void put_unichar_attr_at(int line, int col, unichar ch, int attr);
     void draw_eop(int y, int x, Paragraph &p, bool selected);
+    virtual void do_syntax_highlight(const unistring &str, 
+	    AttributeArray &attributes, int para_num);
 
     ///////////////////////////////////////////////////////////////////////
     //                          Misc
@@ -812,7 +820,6 @@ public:
     const unistring &get_paragraph_text(int i) {
 	return paragraphs[i]->str;
     }
-
 };
 
 #endif
