@@ -803,15 +803,15 @@ void EditBox::detect_syntax()
 
 // Highlight HTML
 
-static void highlight_html(Paragraph &p, EditBox::AttributeArray& attributes)
+static void highlight_html(const unistring &str, EditBox::AttributeArray& attributes)
 {
-    idx_t len = p.str.len();
+    idx_t len = str.len();
     attribute_t html_attr = get_attr(EDIT_HTML_TAG_ATTR);
     bool is_color = contains_color(html_attr);
     bool in_tag = false;
 
     for (idx_t pos = 0; pos < len; pos++) {
-	if (p.str[pos] == '<')
+	if (str[pos] == '<')
 	    in_tag = true;
 	if (in_tag) {
 	    if (is_color)
@@ -819,7 +819,7 @@ static void highlight_html(Paragraph &p, EditBox::AttributeArray& attributes)
 	    else
 		attributes[pos] |= html_attr;
 	}
-	if (p.str[pos] == '>')
+	if (str[pos] == '>')
 	    in_tag = false;
     }
 }
@@ -827,19 +827,19 @@ static void highlight_html(Paragraph &p, EditBox::AttributeArray& attributes)
 // Highlight Email
 
 #define MAX_QUOTE_LEVEL 9
-static void highlight_email(Paragraph &p, EditBox::AttributeArray& attributes)
+static void highlight_email(const unistring &str, EditBox::AttributeArray& attributes)
 {
-    idx_t len = p.str.len();
+    idx_t len = str.len();
     attribute_t quote_attr = A_NORMAL; // silence the compiler.
     bool is_color = false;
     idx_t pos = 0;
     int level = 0;
 
-    while (pos < len && p.str[pos] == ' ')
+    while (pos < len && str[pos] == ' ')
 	pos++;
-    if (pos < len && p.str[pos] == '>')
+    if (pos < len && str[pos] == '>')
 	while (pos < len) {
-	    if (p.str[pos] == '>' && level < MAX_QUOTE_LEVEL) {
+	    if (str[pos] == '>' && level < MAX_QUOTE_LEVEL) {
 		level++;
 		quote_attr = get_attr(EDIT_EMAIL_QUOTE1_ATTR + level - 1);
 		is_color   = contains_color(quote_attr);
@@ -859,20 +859,20 @@ inline bool is_ltr_alpha(unichar ch)
 
 // Highlight underline (*text* and _text_)
 
-static void highlight_underline(Paragraph &p, EditBox::AttributeArray& attributes)
+static void highlight_underline(const unistring &str, EditBox::AttributeArray& attributes)
 {
-    idx_t len = p.str.len();
+    idx_t len = str.len();
     attribute_t underline_attr = get_attr(EDIT_EMPHASIZED_ATTR);
     bool is_color = contains_color(underline_attr);
     bool in_emph = false;
 
     for (idx_t pos = 0; pos < len; pos++) {
-	bool emph_ch = (p.str[pos] == '_' || p.str[pos] == '*');
+	bool emph_ch = (str[pos] == '_' || str[pos] == '*');
 	if (emph_ch) {
 	    // ignore "http://host/show_bug.cgi" and "ticks_per_second" by making
 	    // sure it's not LTR alphanumerics on both sides.
-	    if (pos > 0     && is_ltr_alpha(p.str[pos-1]) &&
-		pos < len-1 && is_ltr_alpha(p.str[pos+1]))
+	    if (pos > 0     && is_ltr_alpha(str[pos-1]) &&
+		pos < len-1 && is_ltr_alpha(str[pos+1]))
 	      emph_ch = false;
 	}
 	if (emph_ch)
@@ -1451,6 +1451,23 @@ void EditBox::redraw_wrapped_paragraph(
     }
 }
 
+void EditBox::do_syntax_highlight(const unistring &str, 
+	    AttributeArray &attributes, int para_num)
+{
+    switch (syn_hlt) {
+    case synhltHTML:
+	highlight_html(str, attributes);
+	break;
+    case synhltEmail:
+	highlight_email(str, attributes);
+	break;
+    default:
+	break;
+    }
+    if (underline_hlt)
+	highlight_underline(str, attributes);
+}
+	
 void EditBox::redraw_paragraph(Paragraph &p, int window_start_line,
 			       bool only_cursor, int para_num)
 {
@@ -1478,20 +1495,7 @@ void EditBox::redraw_paragraph(Paragraph &p, int window_start_line,
 				   p.base_dir(), levels.begin(),
 				   p.breaks_count(), p.line_breaks.begin(),
 				   !bidi_enabled);
-
-	// Do syntax-highlighting
-	switch (syn_hlt) {
-	case synhltHTML:
-	    highlight_html(p, attributes);
-	    break;
-	case synhltEmail:
-	    highlight_email(p, attributes);
-	    break;
-	default:
-	    break;
-	}
-	if (underline_hlt)
-	    highlight_underline(p, attributes);
+	do_syntax_highlight(p.str, attributes, para_num);
     }
 
     //AttributeArray attributes(p.str.len()); 
