@@ -19,6 +19,7 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <unistd.h> // chdir
+#include <sys/wait.h>  // WEXITSTATUS()
 #include <string.h>
 
 #include "editor.h"
@@ -27,9 +28,10 @@
 #include "io.h"
 #include "pathnames.h"
 #include "themes.h"
-#include "utf8.h"   // for show_character_code
+#include "utf8.h"   // used in show_character_code()
 #include "dbg.h"
 #include "transtbl.h"
+#include "helpbox.h"
 
 Editor *Editor::global_instance; // for SIGHUP
 
@@ -39,9 +41,9 @@ Editor *Editor::global_instance; // for SIGHUP
 #define INSERT_HISTORY		1
 #define CHDIR_HISTORY		4
 #define WRITESELECTION_HISTORY	5
-
 #define SPELER_CMD_HISTORY	6
 #define SPELER_ENCODING_HISTORY	7
+#define EXTERNALEDITOR_HISTORY	8
 
 // describe_key() - reads a key event from the keyboard, searches and then
 // prints the description of the correspoding action.
@@ -233,89 +235,16 @@ INTERACTIVE void Editor::quit()
     finished = true; // signal exec()
 }
 
-HelpBox::HelpBox(Editor *aApp, const EditBox &settings)
-{
-    app = aApp;
-    statusmsg.set_text(_("Press F1 or ALT-X to exit help"));
-    statusmsg.highlight();
-    
-    set_undo_size_limit(0);
-    set_read_only(true);
-
-    scroll_step = settings.get_scroll_step();
-    rtl_nsm_display = settings.get_rtl_nsm_display();
-    maqaf_display = settings.get_maqaf_display();
-    
-    show_explicits = false;
-    show_paragraph_endings = true;
-    show_tabs = true;
-}
-
-INTERACTIVE void HelpBox::layout_windows()
-{
-    app->layout_windows();
-    int cols, rows;
-    getmaxyx(stdscr, rows, cols);
-    resize(rows - 1, cols, 0, 0);
-    statusmsg.resize(1, cols, rows - 1, 0);
-}
-
-INTERACTIVE void HelpBox::refresh_and_center()
-{
-    center_line();
-    invalidate_view();
-    statusmsg.invalidate_view();
-    clearok(curscr, TRUE);
-}
-
-void HelpBox::locate_topic(const char *topic)
-{
-    while (search_forward(unistring(u8string(topic))) && cursor.pos != 0)
-	;
-    top_line = CombinedLine(cursor.para, 0);
-    request_update(rgnAll);
-}
-
-// HelpBox::exec() - read events and hand them to the help window.
-
-void HelpBox::exec()
-{
-    set_modal();
-    while (is_modal()) {
-	Event evt;
-	statusmsg.update();
-	update();
-	doupdate();
-	get_next_event(evt, wnd);
-	handle_event(evt);
-    }
-}
-
 // help() - interactive command to load and show the manual.
 
 void Editor::show_help_topic(const char *topic)
 {
     HelpBox helpbox(this, wedit);
     helpbox.layout_windows();
-    u8string dummy_encoding;
-    bool dummy_new;
-    if (!xload_file(&helpbox, get_cfg_filename(USER_MANUAL_FILE),
-		NULL, "UTF-8", dummy_encoding, dummy_new, false)
-	    && !xload_file(&helpbox, get_cfg_filename(SYSTEM_MANUAL_FILE),
-		    NULL, "UTF-8", dummy_encoding, dummy_new, false))
-    {
-	show_file_io_error(_("Cannot open the manual file %s: %s"),
-			get_cfg_filename(SYSTEM_MANUAL_FILE));
-    } else {
-	static Point saved_cursor;
-	if (topic) {
-	    helpbox.locate_topic(topic);
-	} else {
-	    helpbox.set_cursor_position(saved_cursor);
-	    helpbox.center_line();
-	}
+    if (helpbox.load_user_manual()) {
+	if (topic)
+	    helpbox.jump_to_topic(topic);
 	helpbox.exec();
-	helpbox.get_cursor_position(saved_cursor);
 	refresh();
     }
 }
@@ -403,7 +332,7 @@ INTERACTIVE void Editor::write_selection_to_file()
     u8string qry_filename, qry_encoding;
     if (query_filename(wedit.has_selected_text()
 			 ? _("Write selection to:")
-			 : _("Write file to:"),
+			 : _("Write whole text to:"),
 		       qry_filename, qry_encoding,  WRITESELECTION_HISTORY))
 	write_selection_to_file(qry_filename.c_str(),
 		    qry_encoding.empty() ? get_encoding() : qry_encoding.c_str());
@@ -664,10 +593,16 @@ INTERACTIVE void Editor::toggle_graphical_boxes()
 
 void Editor::detect_syntax()
 {
-    if (strstr(get_filename(), ".htm") || strstr(get_filename(), ".HTM"))
+#define NMHAS(EXT) (strstr(get_filename(), EXT))
+    if (NMHAS(".htm") || NMHAS(".HTM"))
 	wedit.set_syn_hlt(EditBox::synhltHTML);
+    else if (NMHAS(".letter") || NMHAS(".article") || NMHAS(".followup") ||
+	     NMHAS(".eml") || NMHAS("SLRN") || NMHAS("pico") || NMHAS("mutt"))
+	// the above strings were taken from Vim's cfg.
+	wedit.set_syn_hlt(EditBox::synhltEmail);
     else
 	wedit.detect_syntax();
+#undef NMHAS
 }
 
 void Editor::set_syntax_auto_detection(bool v)
@@ -716,12 +651,170 @@ INTERACTIVE void Editor::search_forward_next()
 	search_forward();
 }
 
-INTERACTIVE void Editor::escape_to_vim()
+u8string Editor::get_external_editor()
 {
-    dialog.show_message(_("To be done..."));
-    /*endwin();
-    system("vim"); // $EDITOR, them vim, then vi
-    doupdate();*/
+    if (!external_editor.empty())
+	return external_editor;
+
+    // User hasn't specified an editor, so we figure one out ourselves:
+    // First try $EDITOR, them gvim, then vim, then ...
+    if (getenv("EDITOR") && *getenv("EDITOR"))
+	return getenv("EDITOR");
+    if (terminal::under_x11() && has_prog("gvim"))
+	return "gvim -f"; // `-f' = not to fork and detach
+    if (has_prog("vim"))
+	return "vim";
+    if (has_prog("emacs"))
+	return "emacs";
+    if (has_prog("pico"))
+	return "pico";
+    return "vi";
+}
+
+void Editor::set_external_editor(const char *cmd)
+{
+    external_editor = cmd;
+}
+
+INTERACTIVE void Editor::external_edit_prompt()
+{
+    external_edit(true);
+}
+
+INTERACTIVE void Editor::external_edit_no_prompt()
+{
+    external_edit(false);
+}
+
+// external_edit() launches an external editor to edit the file
+// and then reload it.
+
+void Editor::external_edit(bool prompt)
+{
+    // Step 1: we may first need to save the file.
+
+    if (is_untitled()) {
+	if (dialog.ask_yes_or_no(_("First I must save this buffer as a file; is it OK with you?")))
+	    save_file();
+    } else if (wedit.is_modified()) {
+	if (dialog.ask_yes_or_no(_("Buffer was modified and I must save it first; is it OK with you?")))
+	    save_file();
+    }
+    if (is_untitled() || wedit.is_modified())
+	return;
+
+    // Step 2: get the editor command
+
+    cstring command = get_external_editor();
+    if (prompt) {
+	unistring inpt = dialog.query(_("External editor:"),
+				      command.c_str(),
+				      EXTERNALEDITOR_HISTORY,
+				      InputLine::cmpltAll);
+	command = u8string(inpt).trim();
+	if (command.empty()) // user aborted
+	    return;
+	set_external_editor(command.c_str());
+    }
+
+    // Step 3: write the cursor location into a temporary file,
+    // pointed to by $GERESH_CURSOR_FILE
+   
+    cstring cursor_file;
+    //cursor_file = tmpnam(NULL); // gives linker warning!
+    cursor_file.cformat("%s/geresh-%ld-cursor.tmp",
+	    getenv("TMPDIR") ? getenv("TMPDIR") : "/tmp",
+	    (long)getpid());
+
+    Point cursor;
+    wedit.get_cursor_position(cursor);
+
+    FILE *cursor_fh;
+    if ((cursor_fh = fopen(cursor_file.c_str(), "w")) != NULL) {
+	fprintf(cursor_fh, "%d %d\n%s\n",
+		cursor.para + 1, cursor.pos + 1, get_filename());
+	fclose(cursor_fh);
+
+	cstring nameval;
+	nameval.cformat("GERESH_CURSOR_FILE=%s", cursor_file.c_str());
+	putenv(strdup(nameval.c_str()));
+    }
+
+    // Step 4: adjust the editor command so the line number is passed.
+
+    if (command.index("vim") != -1) {
+	// With vim we not only pass the column number in addition
+	// to the line number, but we also pass the necessary
+	// command to write the cursor position back into
+	// $GERESH_CURSOR_FILE.
+	cstring basefilename = get_filename();
+	if (basefilename.index('/') != -1)
+	    basefilename = basefilename.substr(basefilename.rindex('/')+1);
+	cstring col_command;
+	if (cursor.pos != 0)
+	    col_command.cformat("-c \"normal %dl\"", cursor.pos);
+	command.cformat("%s -c %d -c \"normal 0\" %s "
+			"-c \"au BufUnload %s call system('echo '.line('.').' '.col('.').' >%s')\"",
+			    command.c_str(),
+			    cursor.para + 1,
+			    col_command.c_str(),
+			    basefilename.c_str(),
+			    cursor_file.c_str());
+    }
+    else if (command.index("vi") != -1 ||
+	     command.index("pico") != -1 ||
+	     command.index("nano") != -1 ||
+	     command.index("emacs") != -1 ||
+	     command.index("mined") != -1)
+    {
+	// The above editors are known to accept a "+line" parameter.
+	command.cformat("%s +%d", command.c_str(), cursor.para + 1);
+    }
+
+    command += " \"";
+    command += get_filename();
+    command += "\"";
+
+    // Step 5: execute the editor.
+
+    cstring msg;
+    msg.cformat("Executing: %s", command.c_str());
+    dialog.show_message(msg.c_str());
+    update_terminal();
+    
+    endwin();
+    int status = system(command.c_str());
+    doupdate();
+   
+    // Step 6: reload the file.
+
+    // I can't just pass 'get_filename()' to load_file(), because
+    // get_filename() returns a pointer to a string which load_file()
+    // modifies (via set_filename()) ...
+    load_file(u8string(get_filename()).c_str(),
+	      u8string(get_encoding()).c_str());
+   
+    // Step 7: read the cursor position from $GERESH_CURSOR_FILE.
+
+    if ((cursor_fh = fopen(cursor_file.c_str(), "r")) != NULL) {
+	int line_no, col_no;
+	fscanf(cursor_fh, "%d %d", &line_no, &col_no);
+	cursor.para = line_no - 1;
+	cursor.pos  = col_no  - 1;
+	wedit.set_cursor_position(cursor);
+	fclose(cursor_fh);
+    } else {
+	wedit.set_cursor_position(cursor);
+    }
+    unlink(cursor_file.c_str());
+
+    if (WIFEXITED(status) && WEXITSTATUS(status) == 127) {
+	msg.cformat(_("Error: command \"%s\" could not be found"),
+			get_external_editor().c_str());
+	dialog.show_message(msg.c_str());
+    }
+
+    refresh_and_center();
 }
 
 // layout_windows() - is called every time the window changes its size.
