@@ -177,6 +177,7 @@ static void help()
 	"                                         variable, or 80)\n"));
 
     printf(_("\nMiscellaneous:\n"
+	"  -x, --extrnal-editor CMD     External editor\n"
 	"  -c, --show-cursor-position BOOL\n"
 	"                               Constantly display the cursor coordinates\n"
 	//"  -n, --show-numbers BOOL      Show line numbers\n"
@@ -367,6 +368,8 @@ int main(int argc, char *argv[])
 	    *speller_cmd      = ""; // "ispell -a";
     const char
 	    *speller_encoding = ""; // "ISO-8859-1";
+    const char
+	    *external_editor  = "";
     const char
 	    *theme = NULL;
     bool syntax_auto_detection = true;
@@ -419,6 +422,7 @@ int main(int argc, char *argv[])
 	{ "underline",	      1, 0, 'U' },
 	{ "visual-cursor",    1, 0, 'L' },
 	{ "theme",	      1, 0, 'g' },
+	{ "external-editor",  1, 0, 'x' },
 	{0, 0, 0, 0}
     };
 #endif
@@ -426,7 +430,7 @@ int main(int argc, char *argv[])
     if (getenv("COLUMNS"))
 	non_interactive_text_width = atoi(getenv("COLUMNS"));
 
-    const char *short_options = "T:e:J:W:w:a:A:k:S:s:u:j:i:P:M:m:c:n:q:f:F:C:H:RvB:b:Vhpt:E:Z:X:Y:Q:D:G:g:U:L:";
+    const char *short_options = "T:e:J:W:w:a:A:k:S:s:u:j:i:P:M:m:c:n:q:f:F:C:H:RvB:b:Vhpt:E:Z:X:Y:Q:D:G:g:U:L:x:";
     int c;
 #ifdef HAVE_GETOPT_LONG
     int long_idx = -1;
@@ -608,6 +612,7 @@ int main(int argc, char *argv[])
 	case 'Z': speller_cmd = optarg; break;
 	case 'X': speller_encoding = optarg; break;
 	case 'g': theme = optarg; break;
+	case 'x': external_editor = optarg; break;
 	case 'V': print_version_flag = true; break;
 	case 'h': help(); break;
 	case '?':
@@ -737,6 +742,7 @@ int main(int argc, char *argv[])
     bde.set_speller_cmd(speller_cmd);
     bde.set_speller_encoding(speller_encoding);
     bde.adjust_speller_cmd();
+    bde.set_external_editor(external_editor);
     bde.set_scrollbar_pos(scrollbar_pos);
     bde.enable_bidi(enable_bidi);
     bde.set_syntax_auto_detection(syntax_auto_detection);
