@@ -119,6 +119,7 @@
 #define HELP_TOPIC_WRAP_STR	"\xD7\xA7\xD7\x99\xD7\xA4\xD7\x95\xD7\x9C\x20\xD7\xA4\xD7\xA1\xD7\xA7\xD7\x90\xD7\x95\xD7\xAA"
 #define HELP_TOPIC_COLORS_STR	"\xD7\xA2\xD7\xA8\xD7\x9B\xD7\x95\xD7\xAA\x20\xD7\xA6\xD7\x91\xD7\xA2\xD7\x99\xD7\x9D"
 #define HELP_TOPIC_ENCODING_STR "\xD7\xA7\xD7\x99\xD7\x93\xD7\x95\xD7\x93\x20\xD7\x94\xD7\xA7\xD7\x91\xD7\xA6\xD7\x99\xD7\x9D"
+#define HELP_TOPIC_EXTED_STR	"\xD7\x94\xD7\xA4\xD7\xA2\xD7\x9C\xD7\xAA\x20\xD7\xA2\xD7\x95\xD7\xA8\xD7\x9A\x20\xD7\x97\xD7\x99\xD7\xA6\xD7\x95\xD7\xA0\xD7\x99"
 
 PulldownMenu FileMenu = {
     { "load_file", N_("~Open...") },
@@ -128,14 +129,18 @@ PulldownMenu FileMenu = {
     { "save_file_as", N_("Save ~As...") },
     { "write_selection_to_file", N_("~Write selection to...") },
     { "-----------" },
+    { "external_edit_prompt",    N_("Launch external ~editor...") },
+    { "external_edit_no_prompt", N_("Launch external editor") },
+    { "xxx", HELP_ITEM, 0, 0, CMD_HELP, 0, HELP_TOPIC_EXTED_STR },
+    { "-----------" },
     { "change_directory", N_("Ch~dir...") },
     { "quit", N_("~Quit") },
     { NULL }
 };
 
 PulldownMenu MovementMenu = {
+    { "move_beginning_of_buffer", N_("Move to the ~beginning of the buffer") },
     { "move_end_of_buffer", N_("Move to the ~end of the buffer") },
-    { "move_beginning_of_buffer", N_("Move to the ~start of the buffer") },
     { "go_to_line", N_("Go to a specific ~line") },
     { "move_last_modification", N_("Jump to the last ~modification point") },
     { "-----------" },
@@ -143,11 +148,12 @@ PulldownMenu MovementMenu = {
     { "key_right", N_("Move a character right") },
     { "move_previous_line", N_("Move to the previous line") },
     { "move_next_line", N_("Move to the next line") },
-    { "move_forward_page", N_("Move to the next page") },
     { "move_backward_page", N_("Move to the previous page") },
-    { "move_forward_char", N_("Move forward a character") },
+    { "move_forward_page", N_("Move to the next page") },
     { "move_backward_char", N_("Move back a character") },
-    { "move_beginning_of_line", N_("Move to the start of the current line") },
+    { "move_forward_char", N_("Move forward a character") },
+    //{ "move_beginning_of_line", N_("Move to the beginning of the current line") },
+    { "key_home", N_("Move to the beginning of the current line") },
     { "move_end_of_line", N_("Move to the end of the current line") },
     { NULL }
 };
@@ -157,8 +163,8 @@ PulldownMenu DeletionMenu = {
     { "delete_forward_char", N_("Delete the character the cursor is on") },
     { "delete_backward_word", N_("Delete to the start of the current or previous word") },
     { "delete_forward_word", N_("Delete to the end of the current or next word") },
-    { "delete_end_of_paragraph", N_("Delete [to] end of paragraph") },
     { "delete_paragraph", N_("Delete the current paragraph") },
+    { "cut_end_of_paragraph", N_("Cut [to] end of paragraph") },
     { NULL }
 };
 
@@ -250,6 +256,60 @@ PulldownMenu EncodingsMenu = {
     { NULL }
 };
 
+PulldownMenu CantillationsCharMenu = {
+    { "xxx", N_("ETNAHTA         (U+0591)"), 0, 0, CMD_CHR, 0x0591 },
+    { "xxx", N_("SEGOL           (U+0592)"), 0, 0, CMD_CHR, 0x0592 },
+    { "xxx", N_("SHALSHELET      (U+0593)"), 0, 0, CMD_CHR, 0x0593 },
+    { "xxx", N_("ZAQEF QATAN     (U+0594)"), 0, 0, CMD_CHR, 0x0594 },
+    { "xxx", N_("ZAQEF GADOL     (U+0595)"), 0, 0, CMD_CHR, 0x0595 },
+    { "xxx", N_("TIPEHA          (U+0596)"), 0, 0, CMD_CHR, 0x0596 },
+    { "xxx", N_("REVIA           (U+0597)"), 0, 0, CMD_CHR, 0x0597 },
+    { "xxx", N_("ZARQA           (U+0598)"), 0, 0, CMD_CHR, 0x0598 },
+    { "xxx", N_("PASHTA          (U+0599)"), 0, 0, CMD_CHR, 0x0599 },
+    { "xxx", N_("YETIV           (U+059A)"), 0, 0, CMD_CHR, 0x059A },
+    { "xxx", N_("TEVIR           (U+059B)"), 0, 0, CMD_CHR, 0x059B },
+    { "xxx", N_("GERESH          (U+059C)"), 0, 0, CMD_CHR, 0x059C },
+    { "xxx", N_("GERESH MUQDAM   (U+059D)"), 0, 0, CMD_CHR, 0x059D },
+    { "xxx", N_("GERSHAYIM       (U+059E)"), 0, 0, CMD_CHR, 0x059E },
+    { "xxx", N_("QARNEY PARA     (U+059F)"), 0, 0, CMD_CHR, 0x059F },
+    { "xxx", N_("TELISHA GEDOLA  (U+05A0)"), 0, 0, CMD_CHR, 0x05A0 },
+    { "xxx", N_("PAZER           (U+05A1)"), 0, 0, CMD_CHR, 0x05A1 },
+    { "xxx", N_("MUNAH           (U+05A3)"), 0, 0, CMD_CHR, 0x05A3 },
+    { "xxx", N_("MAHAPAKH        (U+05A4)"), 0, 0, CMD_CHR, 0x05A4 },
+    { "xxx", N_("MERKHA          (U+05A5)"), 0, 0, CMD_CHR, 0x05A5 },
+    { "xxx", N_("MERKHA KEFULA   (U+05A6)"), 0, 0, CMD_CHR, 0x05A6 },
+    { "xxx", N_("DARGA           (U+05A7)"), 0, 0, CMD_CHR, 0x05A7 },
+    { "xxx", N_("QADMA           (U+05A8)"), 0, 0, CMD_CHR, 0x05A8 },
+    { "xxx", N_("TELISHA QETANA  (U+05A9)"), 0, 0, CMD_CHR, 0x05A9 },
+    { "xxx", N_("YERAH BEN YOMO  (U+05AA)"), 0, 0, CMD_CHR, 0x05AA },
+    { "xxx", N_("OLE             (U+05AB)"), 0, 0, CMD_CHR, 0x05AB },
+    { "xxx", N_("ILUY            (U+05AC)"), 0, 0, CMD_CHR, 0x05AC },
+    { "xxx", N_("DEHI            (U+05AD)"), 0, 0, CMD_CHR, 0x05AD },
+    { "xxx", N_("ZINOR           (U+05AE)"), 0, 0, CMD_CHR, 0x05AE },
+    { "xxx", N_("MASORA CIRCLE   (U+05AF)"), 0, 0, CMD_CHR, 0x05AF },
+    { "-----------" },
+    { "xxx", N_("METEG           (U+05BD)"), 0, 0, CMD_CHR, UNI_HEB_METEG },
+    { "xxx", N_("PASEQ           (U+05C0)"), 0, 0, CMD_CHR, UNI_HEB_PASEQ },
+    { "xxx", N_("SOF PASUQ       (U+05C3)"), 0, 0, CMD_CHR, UNI_HEB_SOF_PASUQ },
+    { NULL }
+};
+
+PulldownMenu ArabicCharMenu = {
+    { "xxx", N_("~FATHATAN         (U+064B)"), 0, 0, CMD_CHR, 0x064B },
+    { "xxx", N_("DAMMATAN         (U+064C)"), 0, 0, CMD_CHR, 0x064C },
+    { "xxx", N_("~KASRATAN         (U+064D)"), 0, 0, CMD_CHR, 0x064D },
+    { "xxx", N_("FATHA            (U+064E)"), 0, 0, CMD_CHR, 0x064E },
+    { "xxx", N_("~DAMMA            (U+064F)"), 0, 0, CMD_CHR, 0x064F },
+    { "xxx", N_("KASRA            (U+0650)"), 0, 0, CMD_CHR, 0x0650 },
+    { "xxx", N_("~SHADDA           (U+0651)"), 0, 0, CMD_CHR, 0x0651 },
+    { "xxx", N_("SUKUN            (U+0652)"), 0, 0, CMD_CHR, 0x0652 },
+    { "xxx", N_("SUPERSCRIPT ALEF (U+0670)"), 0, 0, CMD_CHR, 0x0670 },
+    { "-----------" },
+    { "xxx", N_("ZWJ,  ZERO WIDTH JOINER     (U+200D)"), 0, 0, CMD_CHR, 0x200D },
+    { "xxx", N_("ZWNJ, ZERO WIDTH NON-JOINER (U+200C)"), 0, 0, CMD_CHR, 0x200C },
+    { NULL }
+};
+
 PulldownMenu InsertCharMenu = {
     { "insert_maqaf", N_("Hebrew ~maqaf (U+05BE)") },
     { "-----------" },
@@ -267,11 +327,11 @@ PulldownMenu InsertCharMenu = {
     { "xxx", N_("HATAF QAMATS    (U+05B~3)"), 0, 0, CMD_CHR, UNI_HEB_HATAF_QAMATS },
     { "xxx", N_("~HIRIQ           (U+05B4)"), 0, 0, CMD_CHR, UNI_HEB_HIRIQ },
     { "xxx", N_("TS~ERE           (U+05B5)"), 0, 0, CMD_CHR, UNI_HEB_TSERE },
-    { "xxx", N_("~SEGOL           (U+05B6)"), 0, 0, CMD_CHR, UNI_HEB_SEGOL },
+    { "xxx", N_("SE~GOL           (U+05B6)"), 0, 0, CMD_CHR, UNI_HEB_SEGOL },
     { "xxx", N_("~PATAH           (U+05B7)"), 0, 0, CMD_CHR, UNI_HEB_PATAH },
     { "xxx", N_("~QAMATS          (U+05B8)"), 0, 0, CMD_CHR, UNI_HEB_QAMATS },
     { "xxx", N_("H~OLAM           (U+05B9)"), 0, 0, CMD_CHR, UNI_HEB_HOLAM },
-    { "xxx", N_("QUBUTS          (U+05BB)"), 0, 0, CMD_CHR, UNI_HEB_QUBUTS },
+    { "xxx", N_("Q~UBUTS          (U+05BB)"), 0, 0, CMD_CHR, UNI_HEB_QUBUTS },
     { "xxx", N_("~DAGESH OR MAPIQ (U+05BC)"), 0, 0, CMD_CHR, UNI_HEB_DAGESH_OR_MAPIQ },
     { "xxx", N_("~RAFE            (U+05BF)"), 0, 0, CMD_CHR, UNI_HEB_RAFE },
     { "xxx", N_("SHIN DOT        (U+05C1)"), 0, 0, CMD_CHR, UNI_HEB_SHIN_DOT },
@@ -279,10 +339,11 @@ PulldownMenu InsertCharMenu = {
     { "-----------" },
     { "xxx", N_("GERESH          (U+05F3)"), 0, 0, CMD_CHR, UNI_HEB_GERESH },
     { "xxx", N_("GERSHAYIM       (U+05F4)"), 0, 0, CMD_CHR, UNI_HEB_GERSHAYIM },
-    { "xxx", N_("METEG           (U+05BD)"), 0, 0, CMD_CHR, UNI_HEB_METEG },
-    { "xxx", N_("PASEQ           (U+05C0)"), 0, 0, CMD_CHR, UNI_HEB_PASEQ },
-    { "xxx", N_("SOF PASUQ       (U+05C3)"), 0, 0, CMD_CHR, UNI_HEB_SOF_PASUQ },
-    { NULL }
+    { "xxx", N_("NO-BREAK SPACE  (U+00A0)"), 0, 0, CMD_CHR, 0x00A0 },
+    { "xxx", N_("ZERO WIDTH SPACE(U+200B)"), 0, 0, CMD_CHR, 0x200B },
+    { "-----------" },
+    { "xxx", N_("~Cantillations"), 0, CantillationsCharMenu },
+    { "xxx", N_("~Arabic"), 0, ArabicCharMenu },
 };
 
 PulldownMenu CharactersUtilsMenu = {
@@ -392,7 +453,7 @@ PulldownMenu HighlightMenu = {
     { "menu_set_syn_hlt_html",	N_("~HTML"),	STT_SYNHTML },
     { "menu_set_syn_hlt_email",	N_("~Email"),	STT_SYNEMAIL },
     { "-----------" },
-    { "toggle_underline",	N_("~Highlight *text* and _text_"), STT_UNDERLINE },
+    { "toggle_underline",	N_("Highlight *~text* and _text_"), STT_UNDERLINE },
     { "-----------" },
     { "xxx", HELP_ITEM, 0, 0, CMD_HELP, 0, HELP_TOPIC_SYNHLT_STR },
     { NULL }
