@@ -619,12 +619,24 @@ void get_word_boundaries(const unistring &str, int cursor, int &wbeg, int &wend)
 // erase_special_characters_words() -  erases/modifies characters
 // or words that may cause problems to the speller:
 // 
+// 0. If we're checking emails and the line is quoted (">"), erase it.
 // 1. remove words with combining characters (e.g. Hebrew points)
 // 2. remove ispell's "\"
 // 3. convert Hebrew maqaf to ASCII one.
 
-void erase_special_characters_words(unistring &str)
+void erase_special_characters_words(unistring &str, bool erase_quotes)
 {
+    if (erase_quotes) {
+	// If we're checking emails, erase lines starting
+	// with ">" (with optional preceding spaces).
+	int i = 0;
+	while (i < str.len() && str[i] == ' ')
+	    i++;
+	if (i < str.len() && str[i] == '>') {
+	    for (i = 0; i < str.len(); i++)
+		str[i] = ' ';
+	}
+    }
     for (int i = 0; i < str.len(); i++) {
 	if (str[i] == UNI_HEB_MAQAF)
 	    str[i] = '-';
@@ -714,7 +726,8 @@ void Speller::spell_check(splRng range, EditBox &wedit, SpellerWnd &splwnd)
 	unistring para = wedit.get_paragraph_text(i);
 
 	// erase/modify some characters/words
-	erase_special_characters_words(para);
+	erase_special_characters_words(para,
+		(wedit.get_syn_hlt() == EditBox::synhltEmail) && (range != splRngWord));
 
 	if (i == start_para) {
 	    if (range != splRngAll) {
